@@ -1,4 +1,6 @@
+#include "imconfig.h"
 #include "log.h"
+#include <stdlib.h>
 
 #define DTBUFF 50
 #define DATABUFF DTBUFF+3+10+1+5+1+1
@@ -59,7 +61,7 @@ m_fatal(int exitcode,const char *fmt, ... ) {
  * Logging is inactive - insert dummy functions
  */
 
-void init_log(const char* name,int onoff) {}
+void m_init_log(const char* name,int onoff) {}
 void m_fatal(int exitcode,const char *fmt, ... ) { exit(exitcode); }
 
 
